package grid

import (
	"context"
	"net/http"
	"strconv"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// RemoveCustomBackupPathRequest struct to remove path from the list of custom backup paths
type RemoveCustomBackupPathRequest struct {
	// ID of the grid
	// Required: true
	GID uint64 `url:"gridId" json:"gridId" validate:"required"`

	// Absolute path
	// Required: true
	Path string `url:"path" json:"path" validate:"required"`
}

// RemoveCustomBackupPath remove path from the list of custom backup paths
func (g Grid) RemoveCustomBackupPath(ctx context.Context, req RemoveCustomBackupPathRequest) (bool, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return false, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/grid/removeCustomBackupPath"

	res, err := g.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return false, err
	}

	result, err := strconv.ParseBool(string(res))
	if err != nil {
		return false, err
	}

	return result, nil
}
