package node

import (
	"context"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

// SetVFsNumberRequest struct to set number of VFs for individual NIC on node
type SetVFsNumberRequest struct {
	// Node ID
	// Required: true
	NID uint64 `url:"nid" json:"nid" validate:"required"`

	// PCI address or NIC name
	// Required: true
	NicID string `url:"nicId" json:"nicId" validate:"required"`

	// Number of VF to assign
	// Required: true
	VFNum uint64 `url:"vfNum" json:"vfNum" validate:"required"`

	// Trust
	// Required: true
	Trust bool `url:"trust" json:"trust" validate:"required"`
}

// SetVFsNumber sets number of VFs for individual NIC on node
func (n Node) SetVFsNumber(ctx context.Context, req SetVFsNumberRequest) (string, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return "", validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/node/setVFsNumber"

	res, err := n.client.DecortApiCall(ctx, http.MethodPost, url, req)
	if err != nil {
		return "", err
	}

	return string(res), nil
}
