package resmon

import (
	"context"
	"encoding/json"
	"net/http"

	"repository.basistech.ru/BASIS/decort-golang-sdk/internal/validators"
)

type GetByStackRequest struct {
	// Stack ID
	// Required: true
	StackID uint64 `url:"stackId" json:"stackId" validate:"required"`

	// Start of time period - unixtime
	// Required: false
	StartTime uint64 `url:"starttime,omitempty" json:"starttime,omitempty"`

	// End of time period - unixtime
	// Required: true
	EndTime uint64 `url:"endtime,omitempty" json:"endtime,omitempty"`
}

// Get a grid resource monitoring for the specified time period
func (r Resmon) GetByStack(ctx context.Context, req GetByStackRequest) (*GetByStackData, error) {
	res, err := r.GetByStackRaw(ctx, req)
	if err != nil {
		return nil, err
	}

	info := GetByStackData{}

	err = json.Unmarshal(res, &info)
	if err != nil {
		return nil, err
	}

	return &info, nil
}

// GetRaw gets information about compute as an array of bytes
func (r Resmon) GetByStackRaw(ctx context.Context, req GetByStackRequest) ([]byte, error) {
	err := validators.ValidateRequest(req)
	if err != nil {
		return nil, validators.ValidationErrors(validators.GetErrors(err))
	}

	url := "/cloudbroker/resmon/getByStack"

	res, err := r.client.DecortApiCall(ctx, http.MethodPost, url, req)
	return res, err
}
